==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumemdetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包报量报告物资扣款子表
 * 
 * @author generator
 * 
 */
public class SubcontractingvolumemdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 编码
    private java.lang.String billName; // 物资名称
    private java.lang.String unit; // 单位
    private java.math.BigDecimal unitprice; // 单价(元)
    private java.math.BigDecimal budgetquantity; // 预算数量
    private java.math.BigDecimal actualConsumption; // 实际消耗数量
    private java.math.BigDecimal excessdosage; // 超用量
    private java.math.BigDecimal overdraftDeduction; // 超用扣款
    private java.lang.String withholding; // 代扣款
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 物资名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 单价(元)
     */
    public java.math.BigDecimal getUnitprice() {
        return unitprice;
    }

    /**
     * 单价(元)
     */
    public void setUnitprice(java.math.BigDecimal unitprice) {
        this.unitprice = unitprice;
    }
    /**
     * 预算数量
     */
    public java.math.BigDecimal getBudgetquantity() {
        return budgetquantity;
    }

    /**
     * 预算数量
     */
    public void setBudgetquantity(java.math.BigDecimal budgetquantity) {
        this.budgetquantity = budgetquantity;
    }
    /**
     * 实际消耗数量
     */
    public java.math.BigDecimal getActualConsumption() {
        return actualConsumption;
    }

    /**
     * 实际消耗数量
     */
    public void setActualConsumption(java.math.BigDecimal actualConsumption) {
        this.actualConsumption = actualConsumption;
    }
    /**
     * 超用量
     */
    public java.math.BigDecimal getExcessdosage() {
        return excessdosage;
    }

    /**
     * 超用量
     */
    public void setExcessdosage(java.math.BigDecimal excessdosage) {
        this.excessdosage = excessdosage;
    }
    /**
     * 超用扣款
     */
    public java.math.BigDecimal getOverdraftDeduction() {
        return overdraftDeduction;
    }

    /**
     * 超用扣款
     */
    public void setOverdraftDeduction(java.math.BigDecimal overdraftDeduction) {
        this.overdraftDeduction = overdraftDeduction;
    }
    /**
     * 代扣款
     */
    public java.lang.String getWithholding() {
        return withholding;
    }

    /**
     * 代扣款
     */
    public void setWithholding(java.lang.String withholding) {
        this.withholding = withholding;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20220902.091149-128-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumemdetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包报量报告物资扣款子表
 * 
 * @author generator
 * 
 */
public class SubcontractingvolumemdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String billCode; // 编码
    private java.lang.String billName; // 物资名称
    private java.lang.String unit; // 单位
    private java.math.BigDecimal mUnitprice; // 单价(元)
    private java.math.BigDecimal budgetquantity; // 预算数量
    private java.math.BigDecimal actualConsumption; // 实际消耗数量
    private java.math.BigDecimal excessdosage; // 超用量
    private java.math.BigDecimal overdraftDeduction; // 超用扣款
    private java.lang.String withholding; // 代扣款
    private java.lang.String errorMsg; // 错误信息


    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getBillName() {
        return billName;
    }

    /**
     * 物资名称
     */
    public void setBillName(java.lang.String billName) {
        this.billName = billName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getmUnitprice() {
        return mUnitprice;
    }

    public void setmUnitprice(BigDecimal mUnitprice) {
        this.mUnitprice = mUnitprice;
    }

    /**
     * 预算数量
     */
    public java.math.BigDecimal getBudgetquantity() {
        return budgetquantity;
    }

    /**
     * 预算数量
     */
    public void setBudgetquantity(java.math.BigDecimal budgetquantity) {
        this.budgetquantity = budgetquantity;
    }
    /**
     * 实际消耗数量
     */
    public java.math.BigDecimal getActualConsumption() {
        return actualConsumption;
    }

    /**
     * 实际消耗数量
     */
    public void setActualConsumption(java.math.BigDecimal actualConsumption) {
        this.actualConsumption = actualConsumption;
    }
    /**
     * 超用量
     */
    public java.math.BigDecimal getExcessdosage() {
        return excessdosage;
    }

    /**
     * 超用量
     */
    public void setExcessdosage(java.math.BigDecimal excessdosage) {
        this.excessdosage = excessdosage;
    }
    /**
     * 超用扣款
     */
    public java.math.BigDecimal getOverdraftDeduction() {
        return overdraftDeduction;
    }

    /**
     * 超用扣款
     */
    public void setOverdraftDeduction(java.math.BigDecimal overdraftDeduction) {
        this.overdraftDeduction = overdraftDeduction;
    }
    /**
     * 代扣款
     */
    public java.lang.String getWithholding() {
        return withholding;
    }

    /**
     * 代扣款
     */
    public void setWithholding(java.lang.String withholding) {
        this.withholding = withholding;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}
